package betterquesting.api2.client.gui.resources.textures;

import betterquesting.api.utils.JsonHelper;
import betterquesting.api2.client.gui.misc.GuiPadding;
import betterquesting.api2.client.gui.misc.GuiRectangle;
import betterquesting.api2.client.gui.misc.IGuiRect;
import betterquesting.api2.client.gui.resources.colors.GuiColorStatic;
import betterquesting.api2.client.gui.resources.colors.IGuiColor;
import com.google.gson.JsonObject;
import cpw.mods.fml.client.config.GuiUtils;
import net.minecraft.client.Minecraft;
import net.minecraft.client.renderer.OpenGlHelper;
import net.minecraft.util.ResourceLocation;
import org.lwjgl.opengl.GL11;

/* loaded from: betterquesting_api2_client_gui_resources_textures.jar:betterquesting/api2/client/gui/resources/textures/SlicedTexture.class */
public class SlicedTexture implements IGuiTexture {
    private static final IGuiColor defColor = new GuiColorStatic(255, 255, 255, 255);
    private final ResourceLocation texture;
    private final IGuiRect texBounds;
    private final GuiPadding texBorder;
    private SliceMode sliceMode = SliceMode.SLICED_TILE;

    /* loaded from: betterquesting_api2_client_gui_resources_textures.jar:betterquesting/api2/client/gui/resources/textures/SlicedTexture$SliceMode.class */
    public enum SliceMode {
        STRETCH,
        SLICED_TILE,
        SLICED_STRETCH
    }

    public SlicedTexture(ResourceLocation tex, IGuiRect bounds, GuiPadding border) {
        this.texture = tex;
        this.texBounds = bounds;
        this.texBorder = border;
    }

    @Override // betterquesting.api2.client.gui.resources.textures.IGuiTexture
    public void drawTexture(int x, int y, int width, int height, float zLevel, float partialTick) {
        drawTexture(x, y, width, height, zLevel, partialTick, defColor);
    }

    @Override // betterquesting.api2.client.gui.resources.textures.IGuiTexture
    public void drawTexture(int x, int y, int width, int height, float zLevel, float partialTick, IGuiColor color) {
        if (width <= 0 || height <= 0) {
            return;
        }
        int w = Math.max(width, this.texBorder.getLeft() + this.texBorder.getRight());
        int h = Math.max(height, this.texBorder.getTop() + this.texBorder.getBottom());
        int dx = x;
        int dy = y;
        GL11.glPushMatrix();
        color.applyGlColor();
        GL11.glEnable(3042);
        OpenGlHelper.func_148821_a(770, 771, 1, 0);
        if (w != width || h != height) {
            dx = 0;
            dy = 0;
            GL11.glTranslatef(x, y, 0.0f);
            GL11.glScaled(width / w, height / h, 1.0d);
        }
        if (this.sliceMode == SliceMode.SLICED_TILE) {
            drawContinuousTexturedBox(this.texture, dx, dy, this.texBounds.getX(), this.texBounds.getY(), w, h, this.texBounds.getWidth(), this.texBounds.getHeight(), this.texBorder.getTop(), this.texBorder.getBottom(), this.texBorder.getLeft(), this.texBorder.getRight(), zLevel);
        } else if (this.sliceMode == SliceMode.SLICED_STRETCH) {
            int iu = this.texBounds.getX() + this.texBorder.getLeft();
            int iv = this.texBounds.getY() + this.texBorder.getTop();
            int iw = (this.texBounds.getWidth() - this.texBorder.getLeft()) - this.texBorder.getRight();
            int ih = (this.texBounds.getHeight() - this.texBorder.getTop()) - this.texBorder.getBottom();
            float sx = (w - (this.texBounds.getWidth() - iw)) / iw;
            float sy = (h - (this.texBounds.getHeight() - ih)) / ih;
            Minecraft.func_71410_x().field_71446_o.func_110577_a(this.texture);
            GL11.glPushMatrix();
            GL11.glTranslatef(dx, dy, 0.0f);
            GuiUtils.drawTexturedModalRect(0, 0, this.texBounds.getX(), this.texBounds.getY(), this.texBorder.getLeft(), this.texBorder.getTop(), zLevel);
            GL11.glPopMatrix();
            GL11.glPushMatrix();
            GL11.glTranslatef(dx + this.texBorder.getLeft(), dy, 0.0f);
            GL11.glScalef(sx, 1.0f, 1.0f);
            GuiUtils.drawTexturedModalRect(0, 0, this.texBounds.getX() + this.texBorder.getLeft(), this.texBounds.getY(), iw, this.texBorder.getTop(), zLevel);
            GL11.glPopMatrix();
            GL11.glPushMatrix();
            GL11.glTranslatef((dx + w) - this.texBorder.getRight(), dy, 0.0f);
            GuiUtils.drawTexturedModalRect(0, 0, this.texBounds.getX() + this.texBorder.getLeft() + iw, this.texBounds.getY(), this.texBorder.getRight(), this.texBorder.getTop(), zLevel);
            GL11.glPopMatrix();
            GL11.glPushMatrix();
            GL11.glTranslatef(dx, dy + this.texBorder.getTop(), 0.0f);
            GL11.glScalef(1.0f, sy, 1.0f);
            GuiUtils.drawTexturedModalRect(0, 0, this.texBounds.getX(), this.texBounds.getY() + this.texBorder.getTop(), this.texBorder.getLeft(), ih, zLevel);
            GL11.glPopMatrix();
            GL11.glPushMatrix();
            GL11.glTranslatef(dx + this.texBorder.getLeft(), dy + this.texBorder.getTop(), 0.0f);
            GL11.glScalef(sx, sy, 1.0f);
            GuiUtils.drawTexturedModalRect(0, 0, iu, iv, iw, ih, zLevel);
            GL11.glPopMatrix();
            GL11.glPushMatrix();
            GL11.glTranslatef((dx + w) - this.texBorder.getRight(), dy + this.texBorder.getTop(), 0.0f);
            GL11.glScalef(1.0f, sy, 1.0f);
            GuiUtils.drawTexturedModalRect(0, 0, this.texBounds.getX() + this.texBorder.getLeft() + iw, this.texBounds.getY() + this.texBorder.getTop(), this.texBorder.getRight(), ih, zLevel);
            GL11.glPopMatrix();
            GL11.glPushMatrix();
            GL11.glTranslatef(dx, (dy + h) - this.texBorder.getBottom(), 0.0f);
            GuiUtils.drawTexturedModalRect(0, 0, this.texBounds.getX(), this.texBounds.getY() + this.texBorder.getTop() + ih, this.texBorder.getLeft(), this.texBorder.getBottom(), zLevel);
            GL11.glPopMatrix();
            GL11.glPushMatrix();
            GL11.glTranslatef(dx + this.texBorder.getLeft(), (dy + h) - this.texBorder.getBottom(), 0.0f);
            GL11.glScalef(sx, 1.0f, 1.0f);
            GuiUtils.drawTexturedModalRect(0, 0, this.texBounds.getX() + this.texBorder.getLeft(), this.texBounds.getY() + this.texBorder.getTop() + ih, iw, this.texBorder.getBottom(), zLevel);
            GL11.glPopMatrix();
            GL11.glPushMatrix();
            GL11.glTranslatef((dx + w) - this.texBorder.getRight(), (dy + h) - this.texBorder.getBottom(), 0.0f);
            GuiUtils.drawTexturedModalRect(0, 0, this.texBounds.getX() + this.texBorder.getLeft() + iw, this.texBounds.getY() + this.texBorder.getTop() + ih, this.texBorder.getRight(), this.texBorder.getBottom(), zLevel);
            GL11.glPopMatrix();
        } else {
            GL11.glTranslatef(dx, dy, 0.0f);
            GL11.glScalef(w / this.texBounds.getWidth(), h / this.texBounds.getHeight(), 1.0f);
            GL11.glEnable(3042);
            OpenGlHelper.func_148821_a(770, 771, 1, 0);
            Minecraft.func_71410_x().field_71446_o.func_110577_a(this.texture);
            GuiUtils.drawTexturedModalRect(0, 0, this.texBounds.getX(), this.texBounds.getY(), this.texBounds.getWidth(), this.texBounds.getHeight(), zLevel);
        }
        GL11.glPopMatrix();
    }

    @Override // betterquesting.api2.client.gui.resources.textures.IGuiTexture
    public ResourceLocation getTexture() {
        return this.texture;
    }

    @Override // betterquesting.api2.client.gui.resources.textures.IGuiTexture
    public IGuiRect getBounds() {
        return this.texBounds;
    }

    public GuiPadding getBorder() {
        return this.texBorder;
    }

    public SlicedTexture setSliceMode(SliceMode mode) {
        this.sliceMode = mode;
        return this;
    }

    public static SlicedTexture readFromJson(JsonObject json) {
        ResourceLocation res = new ResourceLocation(JsonHelper.GetString(json, "texture", "minecraft:missingno"));
        int slice = JsonHelper.GetNumber(json, "sliceMode", 1).intValue();
        JsonObject jOut = JsonHelper.GetObject(json, "coordinates");
        int ox = JsonHelper.GetNumber(jOut, "u", 0).intValue();
        int oy = JsonHelper.GetNumber(jOut, "v", 0).intValue();
        int ow = JsonHelper.GetNumber(jOut, "w", 48).intValue();
        int oh = JsonHelper.GetNumber(jOut, "h", 48).intValue();
        JsonObject jIn = JsonHelper.GetObject(json, "border");
        int il = JsonHelper.GetNumber(jIn, "l", 16).intValue();
        int it = JsonHelper.GetNumber(jIn, "t", 16).intValue();
        int ir = JsonHelper.GetNumber(jIn, "r", 16).intValue();
        int ib = JsonHelper.GetNumber(jIn, "b", 16).intValue();
        return new SlicedTexture(res, new GuiRectangle(ox, oy, ow, oh), new GuiPadding(il, it, ir, ib)).setSliceMode(SliceMode.values()[slice % 3]);
    }

    private static void drawContinuousTexturedBox(ResourceLocation res, int x, int y, int u, int v, int width, int height, int textureWidth, int textureHeight, int topBorder, int bottomBorder, int leftBorder, int rightBorder, float zLevel) {
        Minecraft.func_71410_x().field_71446_o.func_110577_a(res);
        GL11.glEnable(3042);
        OpenGlHelper.func_148821_a(770, 771, 1, 0);
        int fillerWidth = (textureWidth - leftBorder) - rightBorder;
        int fillerHeight = (textureHeight - topBorder) - bottomBorder;
        if (fillerWidth <= 0 || fillerHeight <= 0) {
            return;
        }
        int canvasWidth = (width - leftBorder) - rightBorder;
        int canvasHeight = (height - topBorder) - bottomBorder;
        int xPasses = canvasWidth / fillerWidth;
        int remainderWidth = canvasWidth % fillerWidth;
        int yPasses = canvasHeight / fillerHeight;
        int remainderHeight = canvasHeight % fillerHeight;
        GuiUtils.drawTexturedModalRect(x, y, u, v, leftBorder, topBorder, zLevel);
        GuiUtils.drawTexturedModalRect(x + leftBorder + canvasWidth, y, u + leftBorder + fillerWidth, v, rightBorder, topBorder, zLevel);
        GuiUtils.drawTexturedModalRect(x, y + topBorder + canvasHeight, u, v + topBorder + fillerHeight, leftBorder, bottomBorder, zLevel);
        GuiUtils.drawTexturedModalRect(x + leftBorder + canvasWidth, y + topBorder + canvasHeight, u + leftBorder + fillerWidth, v + topBorder + fillerHeight, rightBorder, bottomBorder, zLevel);
        int i = 0;
        while (true) {
            if (i >= xPasses + (remainderWidth > 0 ? 1 : 0)) {
                break;
            }
            GuiUtils.drawTexturedModalRect(x + leftBorder + (i * fillerWidth), y, u + leftBorder, v, i == xPasses ? remainderWidth : fillerWidth, topBorder, zLevel);
            GuiUtils.drawTexturedModalRect(x + leftBorder + (i * fillerWidth), y + topBorder + canvasHeight, u + leftBorder, v + topBorder + fillerHeight, i == xPasses ? remainderWidth : fillerWidth, bottomBorder, zLevel);
            int j = 0;
            while (true) {
                if (j < yPasses + (remainderHeight > 0 ? 1 : 0)) {
                    GuiUtils.drawTexturedModalRect(x + leftBorder + (i * fillerWidth), y + topBorder + (j * fillerHeight), u + leftBorder, v + topBorder, i == xPasses ? remainderWidth : fillerWidth, j == yPasses ? remainderHeight : fillerHeight, zLevel);
                    j++;
                }
            }
            i++;
        }
        int j2 = 0;
        while (true) {
            if (j2 < yPasses + (remainderHeight > 0 ? 1 : 0)) {
                GuiUtils.drawTexturedModalRect(x, y + topBorder + (j2 * fillerHeight), u, v + topBorder, leftBorder, j2 == yPasses ? remainderHeight : fillerHeight, zLevel);
                GuiUtils.drawTexturedModalRect(x + leftBorder + canvasWidth, y + topBorder + (j2 * fillerHeight), u + leftBorder + fillerWidth, v + topBorder, rightBorder, j2 == yPasses ? remainderHeight : fillerHeight, zLevel);
                j2++;
            } else {
                return;
            }
        }
    }
}
